@@ -25,7 +25,6 @@
 #include <gtkmm/main.h>
 #include <libgnome/gnome-init.h> // For gnome_program_init().
 #include <libgnomevfsmm/uri.h>
-#include <libgnomecanvasmm.h>
 #include <gtksourceviewmm/init.h>
 #include <glibmm/i18n.h>
 
@@ -130,7 +129,6 @@ main(int argc, char* argv[])
 
     Gtk::Main mainInstance(argc, argv, context);
     Bakery::init();
-    Gnome::Canvas::init();
 
     //Get command-line parameters, if any:
     Glib::ustring input_uri = group.m_arg_filename;
@@ -156,10 +154,15 @@ main(int argc, char* argv[])
 
 
     //Check that PostgreSQL is really available:
-    const bool install_complete = Glom::ConnectionPool::check_postgres_is_available_with_warning();
+    bool install_complete = Glom::ConnectionPool::check_postgres_is_available_with_warning();
     if(!install_complete)
       return -1; //There is no point in going further because the most useful Glom functionality will not work without Postgres. Only a very cut-down Glom client would be useful without self-hosting.
 
+    //Check that the libgda postgres provider is really available:
+    install_complete = Glom::ConnectionPool::check_postgres_gda_client_is_available_with_warning();
+    if(!install_complete)
+      return -1; //There is no point in going further because Glom would not be able to connect to any Postgres servers.
+
 
     // Main app
     Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_main");
